package com.gzlh;

import cn.hutool.core.thread.ThreadUtil;
import com.gzlh.led.client.LedNettyConfig;
import com.gzlh.led.factory.LedFactory;
import com.gzlh.led.handler.ILedHandler;
import com.gzlh.led.properties.LedPropertiesConfig;
import com.gzlh.red.config.RedPropertiesConfig;
import com.gzlh.weighbridge.client.WeighbridgeNettyConfig;

import com.gzlh.red.client.RedNettyConfig;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.ApplicationPidFileWriter;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;

import javax.annotation.PreDestroy;
import javax.annotation.Resource;
import java.io.File;
import java.util.Properties;

@SpringBootApplication
@EnableAsync
@EnableScheduling
@EnableConfigurationProperties
public class WeighbridgeServerApplication implements CommandLineRunner {
    @Resource
    private WeighbridgeNettyConfig weighbridgeNettyConfig;
    @Resource
    private LedNettyConfig ledNettyConfig;
    @Resource
    private RedNettyConfig redNettyConfig;
    @Resource
    private RedPropertiesConfig redPropertiesConfig;
    @Resource
    private LedPropertiesConfig ledPropertiesConfig;
    @Resource
    private LedFactory ledFactory;


    public static void main(String[] args) {
        Properties properties = System.getProperties();
        String rootPath = properties.getProperty("user.dir");
        SpringApplication application = new SpringApplication(WeighbridgeServerApplication.class);
        application.addListeners(new ApplicationPidFileWriter(rootPath + File.separator + "app.pid"));
        application.run(args);
    }


    @Override
    public void run(String... args) {
        ThreadUtil.execute(() -> weighbridgeNettyConfig.connect());
        if (ledPropertiesConfig.isEnable()) {
            ThreadUtil.execute(() -> ledNettyConfig.connect());
            String msg = "园内称重";
            ledFactory.handler(ledPropertiesConfig.getBrand()).sendMsg(msg);
        }
        if (redPropertiesConfig.isEnable()) {
            ThreadUtil.execute(() -> redNettyConfig.connect());
        }
    }

    @PreDestroy
    public void close() {
        weighbridgeNettyConfig.close();
        ledNettyConfig.close();
        redNettyConfig.close();
    }
}
