package com.gzlh.weighbridge.server;

import cn.hutool.core.thread.ThreadUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONUtil;
import com.gzlh.api.CheckCarNumberBO;
import com.gzlh.config.ApplicationConfig;
import com.gzlh.led.factory.LedFactory;
import com.gzlh.led.properties.LedPropertiesConfig;
import com.gzlh.task.CleanTask;
import com.gzlh.task.UploadTask;
import com.gzlh.utils.ResultJson;
import com.gzlh.weighbridge.brand.WeighbridgeBrandType;
import com.gzlh.weighbridge.config.WeighbridgePropertiesConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;


@Service
@Slf4j
public class WeighbridgeReqService {

    @Resource
    private ApplicationConfig applicationConfig;

    @Resource
    private WeighbridgePropertiesConfig weighbridgePropertiesConfig;

    @Resource
    private LedFactory ledFactory;
    @Resource
    private LedPropertiesConfig ledPropertiesConfig;


    /**
     * 处理磅数---单位是kg
     *
     * @param weight
     */
    public void handler(Integer weight) {
        String channelName = applicationConfig.getChannelName();
        String serverUrl = applicationConfig.getServerUrl();
        if (weight == 0) {
            //离开地磅则清除--------->
            CacheManager.clean(channelName, serverUrl);
            return;
        }
        //小于设定值则不要
        if (weight < weighbridgePropertiesConfig.getMinKg()) {
            return;
        }
        CacheManager.add(weight);
        Integer maxCountWeight = CacheManager.getMaxCountWeight();
        if (maxCountWeight != -1) {
            ledFactory.handler(ledPropertiesConfig.getBrand()).sendMsg("重量" + maxCountWeight + "kg");
            ThreadUtil.execute(new UploadTask(applicationConfig.getServerUrl(), channelName, maxCountWeight));
        }
    }


    public void handlerV2(int weight) {
        String channelName = applicationConfig.getChannelName();
        String serverUrl = applicationConfig.getServerUrl();
        if (weight == 0) {
            //离开地磅则清除--------->
            CacheManager.clean(channelName, serverUrl);
            CheckManager.setStop();
            return;
        }
        //log.info(WeighbridgeBrandType.NINGBO_KELI.getBrand() + "地磅:{}", weight);
        //小于设定值则不要
        if (weight < weighbridgePropertiesConfig.getMinKg()) {
            return;
        }
        if (CheckManager.check()) {
            CheckManager.add(weight);
        }
    }
    }

